@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: heist
-version: 0.5.3
-id: heist-0.5.3-6c7bb315ae3b5aa3d6916dd0b5c97702
+version: 0.7.0.1
+id: heist-0.7.0.1-6b6dc23345389b0d6415f5b21dd341db
 
 license: BSD3
 copyright:
@@ -9,8 +9,8 @@ maintainer: snap@snapframework.com
 stability:
 homepage: http://snapframework.com/
 package-url:
-description: An xhtml templating system
-category: Web
+description: An (x)html templating system
+category: Web, Snap
 author: Doug Beardsley, Gregory Collins
 pkgpath: textproc/hs-heist
 exposed: True
@@ -26,16 +26,15 @@ exposed-modules: Text.Templating.Heist
                  Text.Templating.Heist.TemplateDirectory
 hidden-modules: Text.Templating.Heist.Internal
                 Text.Templating.Heist.Types
-import-dirs: /usr/local/lib/ghc/heist-0.5.3
-library-dirs: /usr/local/lib/ghc/heist-0.5.3
-hs-libraries: HSheist-0.5.3
+import-dirs: /usr/local/lib/ghc/heist-0.7.0.1
+library-dirs: /usr/local/lib/ghc/heist-0.7.0.1
+hs-libraries: HSheist-0.7.0.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
 depends: MonadCatchIO-transformers-0.2.2.0-21f55e3743ac58803f508355a9eecc56
-         attoparsec-0.8.6.1-0be93c0db37da3d9d9d5934e440ceea4
-         attoparsec-text-0.8.5.1-f471e48decfcb8c1807ae117fe017588
+         attoparsec-0.10.1.0-fbbd15f07775c506a88ff9688f1e3d80
          base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
          blaze-builder-0.2.1.4-bfcede572046050679f95fe80b55244e
          bytestring-0.9.1.10-4e62762ee9b2a5d0cc5bc2fbaaeefd53
@@ -55,6 +54,6 @@ cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-heist-0.5.3/html/heist.haddock
-haddock-html: /usr/local/share/doc/hs-heist-0.5.3/html
+haddock-interfaces: /usr/local/share/doc/hs-heist-0.7.0.1/html/heist.haddock
+haddock-html: /usr/local/share/doc/hs-heist-0.7.0.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
